@@ -3,12 +3,13 @@ Main interface for mediatailor service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.mediatailor import (
+    from mypy_boto3_mediatailor import (
         Client,
         ListPlaybackConfigurationsPaginator,
         MediaTailorClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -16,6 +17,7 @@ Usage::
     session_client: MediaTailorClient = session.client("mediatailor")
 
     list_playback_configurations_paginator: ListPlaybackConfigurationsPaginator = client.get_paginator("list_playback_configurations")
+    ```
 """
 from mypy_boto3_mediatailor.client import MediaTailorClient as Client, MediaTailorClient
 from mypy_boto3_mediatailor.paginator import ListPlaybackConfigurationsPaginator
