@@ -3,9 +3,11 @@ Main interface for mediatailor service type definitions.
 
 Usage::
 
-    from mypy_boto3.mediatailor.type_defs import AvailSuppressionTypeDef
+    ```python
+    from mypy_boto3_mediatailor.type_defs import AvailSuppressionTypeDef
 
     data: AvailSuppressionTypeDef = {...}
+    ```
 """
 import sys
 from typing import Dict, List
